/**
 * This file includes functions for interacting with an ADC
 *
 * Written for: TI ADS8698 8-channel ADC
 *
 * Connections:
 *    Function | ADC Pin     | AVR Port   | Pin # on DIP Atmega328P
 *   ----------+-------------+------------+-------------------------
 *    Data In  |  1 (SDI)    | PB3 (MOSI) | 17
 *    Reset    |  2 (RST)    | PC0        | 23
 *    Data Out | 36 (SDO)    | PB4 (MISO) | 18
 *    Clock    | 37 (SCLK)   | PB5 (SCK)  | 19
 *    Chip Sel.| 38 (CS)     | PC1        | 24
 */

#include <avr/io.h>
#include <util/delay.h>

#include "include/spi.h"
#include "include/ads8698.h"

/* Initialize the ADC. */
void ADS8698_init(void) {

    // Start SPI.
    SPI_init();

    // Set RST and CS as outputs.
    DDRC |= (1<<DDC0) | (1<<DDC1);

    // Pull RST and CS high.
    PORTC |= _BV(PORTC0);
    PORTC |= _BV(PORTC1);

    // Reset the ADC.
    ADS8698_reset();

    // Start measurements
    ADS8698_send_command(ADS8698_RESET);
    SPI_transmit('H');
    SPI_transmit('e');
    SPI_transmit('l');
    SPI_transmit('l');
    SPI_transmit('o');
    SPI_transmit('!');
}

/* Set the input range on the ADC. */
void ADS8698_set_range(ADS8698_range range) {
    // TODO
    return;
}

/* Write to a register on the ADC. */
void ADS8698_write_register(uint8_t address, uint8_t data) {
    // TODO
    return;
}

/* Send a command to the ADC. */
void ADS8698_send_command(ADS8698_command command) {
    // TODO
    return;
}

/* Reset the ADC.
 *
 * Pull RST low for 70ns (instructions: 40-100ns).
 * See datasheet section 8.4.1.1.6.
 */
void ADS8698_reset(void) {
    PORTC &= ~_BV(PORTC0);
    _delay_us(0.47);
    PORTC |= _BV(PORTC0);
}
